function [] = showPressureCentroidTimePlot(myfilename)
[pRaw_left pRaw_right pRawTime pFilt_left pFilt_right pFiltTime acc_combined accTime joint_pos joint_vel joint_effort joint_time ] = loadAllRTP(myfilename);

UNITS_PER_N = 1600;

% subsample the pressure like the robot software would
[pRaw_left_sub pRawTime_sub] = subsamplePressureVector(pRaw_left, pRawTime);
[pRaw_right_sub pRawTime_sub] = subsamplePressureVector(pRaw_right, pRawTime);
[pFilt_left_sub pFiltTime_sub] = subsamplePressureVector(pFilt_left, pFiltTime);
[pFilt_right_sub pFiltTime_sub] = subsamplePressureVector(pFilt_right, pFiltTime);

% convert to Newtons
pFilt_left_sub = pFilt_left_sub/UNITS_PER_N;
pFilt_right_sub = pFilt_right_sub/UNITS_PER_N;
pRaw_right_sub = pRaw_right_sub/UNITS_PER_N;
pRaw_left_sub = pRaw_left_sub/UNITS_PER_N;


% start our time vectors from 0
toffset = pRawTime_sub(1);
pRawTime_sub = pRawTime_sub - toffset;
pFiltTime_sub = pFiltTime_sub - toffset;
accTime = accTime - toffset;
joint_time = joint_time - toffset;
tstart = pRawTime_sub(1);
tend = pRawTime_sub(end);

% get the centroids over time
[xl yl] = getPressureVectorCOM(pRaw_left_sub);
[xr yr] = getPressureVectorCOM(pRaw_right_sub);

% get the bp sum of the pressure vector
[b_lp,a_lp] = cheby1(1,0.5,[0.8/((1/.041)/2),5/((1/.041)/2)]);
lfPressure_right = filter(b_lp,a_lp,pRaw_right_sub);
lfPressure_left = filter(b_lp,a_lp,pRaw_left_sub);
lfSum_right = sumPressureVectorFingerpad(lfPressure_right);
lfSum_left = sumPressureVectorFingerpad(lfPressure_left);

% plot the centroid over time per finger
subplot(4,1,1);
plot(pRawTime_sub, pRaw_right_sub);
title('left-right Pressure');
my_xlim = xlim;
my_ylim = ylim;

%{
subplot(4,1,2);
plot3(pFiltTime_sub, xr,yr);
title('Right Finger X-Y Centroid');
%}

subplot(4,1,2);
plot(pRawTime_sub,abs(lfSum_right),pRawTime_sub,abs(lfSum_left));
title('bandpassed left-right forces')
xlim(my_xlim);

% plot the band-passed centroids
[b_lp,a_lp] = cheby1(1,0.5,[1.0/((1/.041)/2),3/((1/.041)/2)]);
xl_bp = filter(b_lp,a_lp,xl);
yl_bp = filter(b_lp,a_lp,yl);
subplot(4,1,3);
plot(pFiltTime_sub,abs(xl_bp)/2.0,pFiltTime_sub,abs(yl_bp));
title('Left Finger Bandpassed centroids');
xlim(my_xlim);

xr_bp = filter(b_lp,a_lp,xr);
yr_bp = filter(b_lp,a_lp,yr);
subplot(4,1,4);
plot(pFiltTime_sub,abs(xr_bp)/2.0,pFiltTime_sub,abs(yr_bp));
title('Right Finger Bandpassed centroids');
xlim(my_xlim);

figure

subplot(3,1,1)



dxl = [0 diff(xl)];
dyl = [0 diff(yl)];
dxr = [0 diff(xr)];
dyr = [0 diff(yr)];

% plot the rate of centroid change over time per finger
subplot(3,1,1);
plot(pFiltTime_sub, dxl,'k', pFiltTime_sub,dyl,'b');
title('Left Finger X-Y Centroid Diff, Abs Sum');
%hold on;
%plot(pFiltTime_sub, abs(dxlf) + abs(dylf), 'k');

subplot(3,1,2);
plot(pFiltTime_sub, dxr,'k', pFiltTime_sub,dyr,'b');
title('Right Finger X-Y Centroid Diff, Abs Sum');
%hold on
%plot(pFiltTime_sub, abs(dxrf) + abs(dyrf) , 'k');


subplot(3,1,3);
plot(pFiltTime_sub, (abs(dxl)+abs(dyl)+abs(dxr)+abs(dyr))/2.0);
title('Abs Sum Left Fingers, Abs Sum Right Fingers');


%{
figure


%construct the curl vector
ddyl_dt = [0 diff(dyl)/.041];
ddxl_dt =  [0 diff(dxl)/.041];
ddyr_dt = [0 diff(dyr)/.041];
ddxr_dt =  [0 diff(dxr)/.041];

curl_l = ddyl_dt./(dxl+0.0000000000001) - ddxl_dt./(dyl+0.00000000001);
curl_r = ddyr_dt./(dxr+0.0000000000001) - ddxr_dt./(dyr+0.00000000001);

%make a first-order lpf
[b,a] = butter(1,1/(10/.041));
curl_l_filt = filter(b,a,curl_l);
curl_r_filt = filter(b,a,curl_r);


subplot(2,1,1);
plot(pFiltTime_sub, curl_l,pFiltTime_sub,curl_l_filt );
title('Left Finger Curl');

subplot(2,1,2);
plot(pFiltTime_sub, curl_r,pFiltTime_sub,curl_r_filt );
title('Right Finger Curl');
%}
