%{
*********************************************************************
 *
 * Software License Agreement (BSD License)
 *
 *  Copyright (c) 2008, Willow Garage, Inc.
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above
 *     copyright notice, this list of conditions and the following
 *     disclaimer in the documentation and/or other materials provided
 *     with the distribution.
 *   * Neither the name of the Willow Garage nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 *  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 *  ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *  POSSIBILITY OF SUCH DAMAGE.
 *
 *  \author Joe Romano
 *********************************************************************/
%}
%
%  @author Joe Romano
%  @brief Method to take in a pressure vector and it's time vector recorded
%  at 1 khz and subsample it down to 1/.041 Hz 
%
function [ pressure_subsampled pressure_subsampled_time] = subsamplePressureVector(pressure_vector, pressureTime, subsample_spacing)
% here we want to:
% make a vector of time/data values subsampling the 1khz pressure/time vectors every time
% we expect the pressure to change (41 ms - every 41st sample)
% BUT - we need to be careful we subsample on the LEADING edge of the
% sigal so that we are working with the most recent data

% if the user didn't enter a subsample_spacing value set the default
if nargin < 3
    subsample_spacing = 41;
end

for k=1:length(pressure_vector(1,:))
    % find the first point where our pressure changes and make this our index
    % to start subsampling on
    pressure_start_value = pressure_vector(1,k);
    pressure_start_value_old = pressure_vector(1,k);
    pressure_start_index = 1;
    while pressure_start_value == pressure_start_value_old 
        pressure_start_value_old = pressure_start_value;
        pressure_start_value = pressure_vector(pressure_start_index,k);
        pressure_start_index = pressure_start_index + 1;
    end

    % now construct our new vector by subsampling every 41 ms (the pressure
    % update rate) starting at the previously found index
    j = 1;                      %index term for our new vector
    for i = pressure_start_index:subsample_spacing:length(pressure_vector(:,k))
            pressure_subsampled(j,k) = pressure_vector(i,k);
            pressure_subsampled_time(j) = pressureTime(i);
            j = j + 1;
    end
end
